ChangeMethod class

Base class for change methods (insert, update, delete).

Implementers

Constructors

ChangeMethod(MethodElement methodElement, String name, DartType returnType, DartType flattenedReturnType, FormalParameterElement parameterElement, Entity entity)

Properties

changesMultipleItems → bool
no setter
entity → Entity
final
flattenedReturnType → DartType
final
hashCode → int
The hash code for this object.
no setteroverride
methodElement → MethodElement
final
name → String
final
parameterElement → FormalParameterElement
final
requiresAsyncModifier → bool
no setter
returnType → DartType
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override