ForeignKey class

Constructors

ForeignKey(String parentName, List<String> parentColumns, List<String> childColumns, ForeignKeyAction onUpdate, ForeignKeyAction onDelete)

Properties

childColumns → List<String>
final
hashCode → int
The hash code for this object.
no setteroverride
onDelete → ForeignKeyAction
final
onUpdate → ForeignKeyAction
final
parentColumns → List<String>
final
parentName → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getDefinition() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override